Module vec

Module vec 

AnyVec implementation and supplemental types.

See the AnyVec documentation for more information.

Structs

AnyVec
A type-erased vector that stores values of a single type.
AnyVecMutRef
A smart pointer that dereferences to a mutable Vec<T>.
AnyVecRef
A smart pointer that dereferences to a Vec<T>.