Type-erased containers
This crate provides type-erased container types that allow storing values of different types behind a common interface.
Overview
The crate provides several type-erased container types:
AnyMap- A map from types to a single value of each typeAnyMultiMap- A map from types to multiple values of each typeAnyVec- A type-erased vector that stores values of a single typeAnyCloneBox- A type-erased box that allows cloning the boxed value
Re-exports
pub use vec::AnyVec;
Modules
Structs
- AnyClone
Box - A type-erased cloneable box that stores any
Clone + Send + Synctype. - AnyMap
- A type-erased map storing values of different types by their
TypeId. - AnyMulti
Map - A type-erased multimap storing multiple values per type.